# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['JobDefinitionArgs', 'JobDefinition']

@pulumi.input_type
class JobDefinitionArgs:
    def __init__(__self__, *,
                 cpu_limit: pulumi.Input[_builtins.int],
                 image_uri: pulumi.Input[_builtins.str],
                 local_storage_capacity: pulumi.Input[_builtins.int],
                 memory_limit: pulumi.Input[_builtins.int],
                 args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 command: Optional[pulumi.Input[_builtins.str]] = None,
                 cron: Optional[pulumi.Input['JobDefinitionCronArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 env: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_references: Optional[pulumi.Input[Sequence[pulumi.Input['JobDefinitionSecretReferenceArgs']]]] = None,
                 startup_commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a JobDefinition resource.
        :param pulumi.Input[_builtins.int] cpu_limit: The amount of vCPU computing resources to allocate to each container running the job.
        :param pulumi.Input[_builtins.str] image_uri: The uri of the container image that will be used for the job run.
        :param pulumi.Input[_builtins.int] local_storage_capacity: The local storage capacity of the job in MiB.
        :param pulumi.Input[_builtins.int] memory_limit: The memory computing resources in MB to allocate to each container running the job.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] args: The arguments that will be passed to the startup command at runtime (in list of string format). Overrides the default arguments defined in the job image. Environment variables and secrets can be included, and will be expanded before the arguments are used.
        :param pulumi.Input[_builtins.str] command: The command that will be run in the container if specified.
        :param pulumi.Input['JobDefinitionCronArgs'] cron: The cron configuration
        :param pulumi.Input[_builtins.str] description: The description of the job
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] env: The environment variables of the container.
        :param pulumi.Input[_builtins.str] name: The name of the job.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the Job is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region of the Job.
        :param pulumi.Input[Sequence[pulumi.Input['JobDefinitionSecretReferenceArgs']]] secret_references: A reference to a secret stored in Secret Manager.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] startup_commands: The command (main executable or entrypoint script) that will be run in the container (in list of string format). Overrides the default command defined in the job image.
        :param pulumi.Input[_builtins.str] timeout: The job run timeout, in Go Time format (ex: `2h30m25s`)
        """
        pulumi.set(__self__, "cpu_limit", cpu_limit)
        pulumi.set(__self__, "image_uri", image_uri)
        pulumi.set(__self__, "local_storage_capacity", local_storage_capacity)
        pulumi.set(__self__, "memory_limit", memory_limit)
        if args is not None:
            pulumi.set(__self__, "args", args)
        if command is not None:
            warnings.warn("""Please use startup_command instead""", DeprecationWarning)
            pulumi.log.warn("""command is deprecated: Please use startup_command instead""")
        if command is not None:
            pulumi.set(__self__, "command", command)
        if cron is not None:
            pulumi.set(__self__, "cron", cron)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if env is not None:
            pulumi.set(__self__, "env", env)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_references is not None:
            pulumi.set(__self__, "secret_references", secret_references)
        if startup_commands is not None:
            pulumi.set(__self__, "startup_commands", startup_commands)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> pulumi.Input[_builtins.int]:
        """
        The amount of vCPU computing resources to allocate to each container running the job.
        """
        return pulumi.get(self, "cpu_limit")

    @cpu_limit.setter
    def cpu_limit(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "cpu_limit", value)

    @_builtins.property
    @pulumi.getter(name="imageUri")
    def image_uri(self) -> pulumi.Input[_builtins.str]:
        """
        The uri of the container image that will be used for the job run.
        """
        return pulumi.get(self, "image_uri")

    @image_uri.setter
    def image_uri(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "image_uri", value)

    @_builtins.property
    @pulumi.getter(name="localStorageCapacity")
    def local_storage_capacity(self) -> pulumi.Input[_builtins.int]:
        """
        The local storage capacity of the job in MiB.
        """
        return pulumi.get(self, "local_storage_capacity")

    @local_storage_capacity.setter
    def local_storage_capacity(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "local_storage_capacity", value)

    @_builtins.property
    @pulumi.getter(name="memoryLimit")
    def memory_limit(self) -> pulumi.Input[_builtins.int]:
        """
        The memory computing resources in MB to allocate to each container running the job.
        """
        return pulumi.get(self, "memory_limit")

    @memory_limit.setter
    def memory_limit(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "memory_limit", value)

    @_builtins.property
    @pulumi.getter
    def args(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The arguments that will be passed to the startup command at runtime (in list of string format). Overrides the default arguments defined in the job image. Environment variables and secrets can be included, and will be expanded before the arguments are used.
        """
        return pulumi.get(self, "args")

    @args.setter
    def args(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "args", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Please use startup_command instead""")
    def command(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The command that will be run in the container if specified.
        """
        return pulumi.get(self, "command")

    @command.setter
    def command(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "command", value)

    @_builtins.property
    @pulumi.getter
    def cron(self) -> Optional[pulumi.Input['JobDefinitionCronArgs']]:
        """
        The cron configuration
        """
        return pulumi.get(self, "cron")

    @cron.setter
    def cron(self, value: Optional[pulumi.Input['JobDefinitionCronArgs']]):
        pulumi.set(self, "cron", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the job
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def env(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The environment variables of the container.
        """
        return pulumi.get(self, "env")

    @env.setter
    def env(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "env", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the job.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the Job is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region of the Job.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="secretReferences")
    def secret_references(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobDefinitionSecretReferenceArgs']]]]:
        """
        A reference to a secret stored in Secret Manager.
        """
        return pulumi.get(self, "secret_references")

    @secret_references.setter
    def secret_references(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobDefinitionSecretReferenceArgs']]]]):
        pulumi.set(self, "secret_references", value)

    @_builtins.property
    @pulumi.getter(name="startupCommands")
    def startup_commands(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The command (main executable or entrypoint script) that will be run in the container (in list of string format). Overrides the default command defined in the job image.
        """
        return pulumi.get(self, "startup_commands")

    @startup_commands.setter
    def startup_commands(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "startup_commands", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The job run timeout, in Go Time format (ex: `2h30m25s`)
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class _JobDefinitionState:
    def __init__(__self__, *,
                 args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 command: Optional[pulumi.Input[_builtins.str]] = None,
                 cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 cron: Optional[pulumi.Input['JobDefinitionCronArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 env: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 image_uri: Optional[pulumi.Input[_builtins.str]] = None,
                 local_storage_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_references: Optional[pulumi.Input[Sequence[pulumi.Input['JobDefinitionSecretReferenceArgs']]]] = None,
                 startup_commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering JobDefinition resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] args: The arguments that will be passed to the startup command at runtime (in list of string format). Overrides the default arguments defined in the job image. Environment variables and secrets can be included, and will be expanded before the arguments are used.
        :param pulumi.Input[_builtins.str] command: The command that will be run in the container if specified.
        :param pulumi.Input[_builtins.int] cpu_limit: The amount of vCPU computing resources to allocate to each container running the job.
        :param pulumi.Input['JobDefinitionCronArgs'] cron: The cron configuration
        :param pulumi.Input[_builtins.str] description: The description of the job
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] env: The environment variables of the container.
        :param pulumi.Input[_builtins.str] image_uri: The uri of the container image that will be used for the job run.
        :param pulumi.Input[_builtins.int] local_storage_capacity: The local storage capacity of the job in MiB.
        :param pulumi.Input[_builtins.int] memory_limit: The memory computing resources in MB to allocate to each container running the job.
        :param pulumi.Input[_builtins.str] name: The name of the job.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the Job is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region of the Job.
        :param pulumi.Input[Sequence[pulumi.Input['JobDefinitionSecretReferenceArgs']]] secret_references: A reference to a secret stored in Secret Manager.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] startup_commands: The command (main executable or entrypoint script) that will be run in the container (in list of string format). Overrides the default command defined in the job image.
        :param pulumi.Input[_builtins.str] timeout: The job run timeout, in Go Time format (ex: `2h30m25s`)
        """
        if args is not None:
            pulumi.set(__self__, "args", args)
        if command is not None:
            warnings.warn("""Please use startup_command instead""", DeprecationWarning)
            pulumi.log.warn("""command is deprecated: Please use startup_command instead""")
        if command is not None:
            pulumi.set(__self__, "command", command)
        if cpu_limit is not None:
            pulumi.set(__self__, "cpu_limit", cpu_limit)
        if cron is not None:
            pulumi.set(__self__, "cron", cron)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if env is not None:
            pulumi.set(__self__, "env", env)
        if image_uri is not None:
            pulumi.set(__self__, "image_uri", image_uri)
        if local_storage_capacity is not None:
            pulumi.set(__self__, "local_storage_capacity", local_storage_capacity)
        if memory_limit is not None:
            pulumi.set(__self__, "memory_limit", memory_limit)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_references is not None:
            pulumi.set(__self__, "secret_references", secret_references)
        if startup_commands is not None:
            pulumi.set(__self__, "startup_commands", startup_commands)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter
    def args(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The arguments that will be passed to the startup command at runtime (in list of string format). Overrides the default arguments defined in the job image. Environment variables and secrets can be included, and will be expanded before the arguments are used.
        """
        return pulumi.get(self, "args")

    @args.setter
    def args(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "args", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Please use startup_command instead""")
    def command(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The command that will be run in the container if specified.
        """
        return pulumi.get(self, "command")

    @command.setter
    def command(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "command", value)

    @_builtins.property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The amount of vCPU computing resources to allocate to each container running the job.
        """
        return pulumi.get(self, "cpu_limit")

    @cpu_limit.setter
    def cpu_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "cpu_limit", value)

    @_builtins.property
    @pulumi.getter
    def cron(self) -> Optional[pulumi.Input['JobDefinitionCronArgs']]:
        """
        The cron configuration
        """
        return pulumi.get(self, "cron")

    @cron.setter
    def cron(self, value: Optional[pulumi.Input['JobDefinitionCronArgs']]):
        pulumi.set(self, "cron", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the job
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def env(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The environment variables of the container.
        """
        return pulumi.get(self, "env")

    @env.setter
    def env(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "env", value)

    @_builtins.property
    @pulumi.getter(name="imageUri")
    def image_uri(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The uri of the container image that will be used for the job run.
        """
        return pulumi.get(self, "image_uri")

    @image_uri.setter
    def image_uri(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "image_uri", value)

    @_builtins.property
    @pulumi.getter(name="localStorageCapacity")
    def local_storage_capacity(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The local storage capacity of the job in MiB.
        """
        return pulumi.get(self, "local_storage_capacity")

    @local_storage_capacity.setter
    def local_storage_capacity(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_storage_capacity", value)

    @_builtins.property
    @pulumi.getter(name="memoryLimit")
    def memory_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The memory computing resources in MB to allocate to each container running the job.
        """
        return pulumi.get(self, "memory_limit")

    @memory_limit.setter
    def memory_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "memory_limit", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the job.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the Job is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region of the Job.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="secretReferences")
    def secret_references(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobDefinitionSecretReferenceArgs']]]]:
        """
        A reference to a secret stored in Secret Manager.
        """
        return pulumi.get(self, "secret_references")

    @secret_references.setter
    def secret_references(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobDefinitionSecretReferenceArgs']]]]):
        pulumi.set(self, "secret_references", value)

    @_builtins.property
    @pulumi.getter(name="startupCommands")
    def startup_commands(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The command (main executable or entrypoint script) that will be run in the container (in list of string format). Overrides the default command defined in the job image.
        """
        return pulumi.get(self, "startup_commands")

    @startup_commands.setter
    def startup_commands(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "startup_commands", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The job run timeout, in Go Time format (ex: `2h30m25s`)
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "timeout", value)


warnings.warn("""scaleway.index/jobdefinition.JobDefinition has been deprecated in favor of scaleway.job/definition.Definition""", DeprecationWarning)


@pulumi.type_token("scaleway:index/jobDefinition:JobDefinition")
class JobDefinition(pulumi.CustomResource):
    warnings.warn("""scaleway.index/jobdefinition.JobDefinition has been deprecated in favor of scaleway.job/definition.Definition""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 command: Optional[pulumi.Input[_builtins.str]] = None,
                 cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 cron: Optional[pulumi.Input[Union['JobDefinitionCronArgs', 'JobDefinitionCronArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 env: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 image_uri: Optional[pulumi.Input[_builtins.str]] = None,
                 local_storage_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['JobDefinitionSecretReferenceArgs', 'JobDefinitionSecretReferenceArgsDict']]]]] = None,
                 startup_commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages a Scaleway Serverless Job Definition. For more information, see the [Go API documentation](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/jobs/v1alpha1).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.job.Definition("main",
            name="testjob",
            cpu_limit=140,
            memory_limit=256,
            image_uri="docker.io/alpine:latest",
            command="ls",
            timeout="10m",
            env={
                "foo": "bar",
            },
            cron={
                "schedule": "5 4 1 * *",
                "timezone": "Europe/Paris",
            })
        ```

        ### With Secret Reference

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.job.Definition("main",
            name="testjob",
            cpu_limit=140,
            memory_limit=256,
            image_uri="docker.io/alpine:latest",
            command="ls",
            timeout="10m",
            cron={
                "schedule": "5 4 1 * *",
                "timezone": "Europe/Paris",
            },
            secret_references=[
                {
                    "secret_id": "11111111-1111-1111-1111-111111111111",
                    "file": "/home/dev/secret_file",
                },
                {
                    "secret_id": job_secret["id"],
                    "secret_version": "1",
                    "environment": "FOO",
                },
            ])
        ```

        ## Import

        Serverless Jobs can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/jobDefinition:JobDefinition job fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] args: The arguments that will be passed to the startup command at runtime (in list of string format). Overrides the default arguments defined in the job image. Environment variables and secrets can be included, and will be expanded before the arguments are used.
        :param pulumi.Input[_builtins.str] command: The command that will be run in the container if specified.
        :param pulumi.Input[_builtins.int] cpu_limit: The amount of vCPU computing resources to allocate to each container running the job.
        :param pulumi.Input[Union['JobDefinitionCronArgs', 'JobDefinitionCronArgsDict']] cron: The cron configuration
        :param pulumi.Input[_builtins.str] description: The description of the job
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] env: The environment variables of the container.
        :param pulumi.Input[_builtins.str] image_uri: The uri of the container image that will be used for the job run.
        :param pulumi.Input[_builtins.int] local_storage_capacity: The local storage capacity of the job in MiB.
        :param pulumi.Input[_builtins.int] memory_limit: The memory computing resources in MB to allocate to each container running the job.
        :param pulumi.Input[_builtins.str] name: The name of the job.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the Job is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region of the Job.
        :param pulumi.Input[Sequence[pulumi.Input[Union['JobDefinitionSecretReferenceArgs', 'JobDefinitionSecretReferenceArgsDict']]]] secret_references: A reference to a secret stored in Secret Manager.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] startup_commands: The command (main executable or entrypoint script) that will be run in the container (in list of string format). Overrides the default command defined in the job image.
        :param pulumi.Input[_builtins.str] timeout: The job run timeout, in Go Time format (ex: `2h30m25s`)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: JobDefinitionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages a Scaleway Serverless Job Definition. For more information, see the [Go API documentation](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/jobs/v1alpha1).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.job.Definition("main",
            name="testjob",
            cpu_limit=140,
            memory_limit=256,
            image_uri="docker.io/alpine:latest",
            command="ls",
            timeout="10m",
            env={
                "foo": "bar",
            },
            cron={
                "schedule": "5 4 1 * *",
                "timezone": "Europe/Paris",
            })
        ```

        ### With Secret Reference

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.job.Definition("main",
            name="testjob",
            cpu_limit=140,
            memory_limit=256,
            image_uri="docker.io/alpine:latest",
            command="ls",
            timeout="10m",
            cron={
                "schedule": "5 4 1 * *",
                "timezone": "Europe/Paris",
            },
            secret_references=[
                {
                    "secret_id": "11111111-1111-1111-1111-111111111111",
                    "file": "/home/dev/secret_file",
                },
                {
                    "secret_id": job_secret["id"],
                    "secret_version": "1",
                    "environment": "FOO",
                },
            ])
        ```

        ## Import

        Serverless Jobs can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/jobDefinition:JobDefinition job fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param JobDefinitionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(JobDefinitionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 command: Optional[pulumi.Input[_builtins.str]] = None,
                 cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 cron: Optional[pulumi.Input[Union['JobDefinitionCronArgs', 'JobDefinitionCronArgsDict']]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 env: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 image_uri: Optional[pulumi.Input[_builtins.str]] = None,
                 local_storage_capacity: Optional[pulumi.Input[_builtins.int]] = None,
                 memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['JobDefinitionSecretReferenceArgs', 'JobDefinitionSecretReferenceArgsDict']]]]] = None,
                 startup_commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""JobDefinition is deprecated: scaleway.index/jobdefinition.JobDefinition has been deprecated in favor of scaleway.job/definition.Definition""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = JobDefinitionArgs.__new__(JobDefinitionArgs)

            __props__.__dict__["args"] = args
            __props__.__dict__["command"] = command
            if cpu_limit is None and not opts.urn:
                raise TypeError("Missing required property 'cpu_limit'")
            __props__.__dict__["cpu_limit"] = cpu_limit
            __props__.__dict__["cron"] = cron
            __props__.__dict__["description"] = description
            __props__.__dict__["env"] = env
            if image_uri is None and not opts.urn:
                raise TypeError("Missing required property 'image_uri'")
            __props__.__dict__["image_uri"] = image_uri
            if local_storage_capacity is None and not opts.urn:
                raise TypeError("Missing required property 'local_storage_capacity'")
            __props__.__dict__["local_storage_capacity"] = local_storage_capacity
            if memory_limit is None and not opts.urn:
                raise TypeError("Missing required property 'memory_limit'")
            __props__.__dict__["memory_limit"] = memory_limit
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["secret_references"] = secret_references
            __props__.__dict__["startup_commands"] = startup_commands
            __props__.__dict__["timeout"] = timeout
        super(JobDefinition, __self__).__init__(
            'scaleway:index/jobDefinition:JobDefinition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            command: Optional[pulumi.Input[_builtins.str]] = None,
            cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
            cron: Optional[pulumi.Input[Union['JobDefinitionCronArgs', 'JobDefinitionCronArgsDict']]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            env: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            image_uri: Optional[pulumi.Input[_builtins.str]] = None,
            local_storage_capacity: Optional[pulumi.Input[_builtins.int]] = None,
            memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            secret_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['JobDefinitionSecretReferenceArgs', 'JobDefinitionSecretReferenceArgsDict']]]]] = None,
            startup_commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            timeout: Optional[pulumi.Input[_builtins.str]] = None) -> 'JobDefinition':
        """
        Get an existing JobDefinition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] args: The arguments that will be passed to the startup command at runtime (in list of string format). Overrides the default arguments defined in the job image. Environment variables and secrets can be included, and will be expanded before the arguments are used.
        :param pulumi.Input[_builtins.str] command: The command that will be run in the container if specified.
        :param pulumi.Input[_builtins.int] cpu_limit: The amount of vCPU computing resources to allocate to each container running the job.
        :param pulumi.Input[Union['JobDefinitionCronArgs', 'JobDefinitionCronArgsDict']] cron: The cron configuration
        :param pulumi.Input[_builtins.str] description: The description of the job
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] env: The environment variables of the container.
        :param pulumi.Input[_builtins.str] image_uri: The uri of the container image that will be used for the job run.
        :param pulumi.Input[_builtins.int] local_storage_capacity: The local storage capacity of the job in MiB.
        :param pulumi.Input[_builtins.int] memory_limit: The memory computing resources in MB to allocate to each container running the job.
        :param pulumi.Input[_builtins.str] name: The name of the job.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the Job is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region of the Job.
        :param pulumi.Input[Sequence[pulumi.Input[Union['JobDefinitionSecretReferenceArgs', 'JobDefinitionSecretReferenceArgsDict']]]] secret_references: A reference to a secret stored in Secret Manager.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] startup_commands: The command (main executable or entrypoint script) that will be run in the container (in list of string format). Overrides the default command defined in the job image.
        :param pulumi.Input[_builtins.str] timeout: The job run timeout, in Go Time format (ex: `2h30m25s`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _JobDefinitionState.__new__(_JobDefinitionState)

        __props__.__dict__["args"] = args
        __props__.__dict__["command"] = command
        __props__.__dict__["cpu_limit"] = cpu_limit
        __props__.__dict__["cron"] = cron
        __props__.__dict__["description"] = description
        __props__.__dict__["env"] = env
        __props__.__dict__["image_uri"] = image_uri
        __props__.__dict__["local_storage_capacity"] = local_storage_capacity
        __props__.__dict__["memory_limit"] = memory_limit
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["secret_references"] = secret_references
        __props__.__dict__["startup_commands"] = startup_commands
        __props__.__dict__["timeout"] = timeout
        return JobDefinition(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def args(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The arguments that will be passed to the startup command at runtime (in list of string format). Overrides the default arguments defined in the job image. Environment variables and secrets can be included, and will be expanded before the arguments are used.
        """
        return pulumi.get(self, "args")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Please use startup_command instead""")
    def command(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The command that will be run in the container if specified.
        """
        return pulumi.get(self, "command")

    @_builtins.property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> pulumi.Output[_builtins.int]:
        """
        The amount of vCPU computing resources to allocate to each container running the job.
        """
        return pulumi.get(self, "cpu_limit")

    @_builtins.property
    @pulumi.getter
    def cron(self) -> pulumi.Output[Optional['outputs.JobDefinitionCron']]:
        """
        The cron configuration
        """
        return pulumi.get(self, "cron")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the job
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def env(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        The environment variables of the container.
        """
        return pulumi.get(self, "env")

    @_builtins.property
    @pulumi.getter(name="imageUri")
    def image_uri(self) -> pulumi.Output[_builtins.str]:
        """
        The uri of the container image that will be used for the job run.
        """
        return pulumi.get(self, "image_uri")

    @_builtins.property
    @pulumi.getter(name="localStorageCapacity")
    def local_storage_capacity(self) -> pulumi.Output[_builtins.int]:
        """
        The local storage capacity of the job in MiB.
        """
        return pulumi.get(self, "local_storage_capacity")

    @_builtins.property
    @pulumi.getter(name="memoryLimit")
    def memory_limit(self) -> pulumi.Output[_builtins.int]:
        """
        The memory computing resources in MB to allocate to each container running the job.
        """
        return pulumi.get(self, "memory_limit")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the job.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the Job is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region of the Job.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="secretReferences")
    def secret_references(self) -> pulumi.Output[Optional[Sequence['outputs.JobDefinitionSecretReference']]]:
        """
        A reference to a secret stored in Secret Manager.
        """
        return pulumi.get(self, "secret_references")

    @_builtins.property
    @pulumi.getter(name="startupCommands")
    def startup_commands(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The command (main executable or entrypoint script) that will be run in the container (in list of string format). Overrides the default command defined in the job image.
        """
        return pulumi.get(self, "startup_commands")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[_builtins.str]:
        """
        The job run timeout, in Go Time format (ex: `2h30m25s`)
        """
        return pulumi.get(self, "timeout")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SamlCertificateArgs', 'SamlCertificate']

@pulumi.input_type
class SamlCertificateArgs:
    def __init__(__self__, *,
                 content: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 saml_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SamlCertificate resource.
        :param pulumi.Input[_builtins.str] content: The content of the SAML certificate
        :param pulumi.Input[_builtins.str] type: The type of the SAML certificate. Possible values are: `signing`, `encryption`.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID. If not provided, the default organization configured in the provider is used.
        :param pulumi.Input[_builtins.str] saml_id: The ID of the SAML configuration. If not provided, the organization's SAML configuration is used.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "type", type)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if saml_id is not None:
            pulumi.set(__self__, "saml_id", saml_id)

    @_builtins.property
    @pulumi.getter
    def content(self) -> pulumi.Input[_builtins.str]:
        """
        The content of the SAML certificate
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "content", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the SAML certificate. Possible values are: `signing`, `encryption`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID. If not provided, the default organization configured in the provider is used.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="samlId")
    def saml_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the SAML configuration. If not provided, the organization's SAML configuration is used.
        """
        return pulumi.get(self, "saml_id")

    @saml_id.setter
    def saml_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "saml_id", value)


@pulumi.input_type
class _SamlCertificateState:
    def __init__(__self__, *,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 origin: Optional[pulumi.Input[_builtins.str]] = None,
                 saml_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SamlCertificate resources.
        :param pulumi.Input[_builtins.str] content: The content of the SAML certificate
        :param pulumi.Input[_builtins.str] expires_at: (String) The expiration date and time of the SAML certificate
        :param pulumi.Input[_builtins.str] organization_id: The organization ID. If not provided, the default organization configured in the provider is used.
        :param pulumi.Input[_builtins.str] origin: (String) The origin of the SAML certificate. Possible values are: `scaleway`, `identity_provider`.
        :param pulumi.Input[_builtins.str] saml_id: The ID of the SAML configuration. If not provided, the organization's SAML configuration is used.
        :param pulumi.Input[_builtins.str] type: The type of the SAML certificate. Possible values are: `signing`, `encryption`.
        """
        if content is not None:
            pulumi.set(__self__, "content", content)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if origin is not None:
            pulumi.set(__self__, "origin", origin)
        if saml_id is not None:
            pulumi.set(__self__, "saml_id", saml_id)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The content of the SAML certificate
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "content", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (String) The expiration date and time of the SAML certificate
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID. If not provided, the default organization configured in the provider is used.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter
    def origin(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (String) The origin of the SAML certificate. Possible values are: `scaleway`, `identity_provider`.
        """
        return pulumi.get(self, "origin")

    @origin.setter
    def origin(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "origin", value)

    @_builtins.property
    @pulumi.getter(name="samlId")
    def saml_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the SAML configuration. If not provided, the organization's SAML configuration is used.
        """
        return pulumi.get(self, "saml_id")

    @saml_id.setter
    def saml_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "saml_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the SAML certificate. Possible values are: `signing`, `encryption`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("scaleway:iam/samlCertificate:SamlCertificate")
class SamlCertificate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 saml_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages SAML certificates for an organization. SAML certificates are used to establish trust between your organization and identity providers. SAML (Security Assertion Markup Language) is an open standard for exchanging authentication and authorization data between parties, specifically between an identity provider and a service provider. This resource allows you to manage SAML certificates in your Scaleway organization.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ### Enable IAM SAML for the default organization and add a signing certificate
        test = scaleway.iam.Saml("test")
        main = scaleway.iam.SamlCertificate("main",
            saml_id=test.id,
            type="signing",
            content="<signing certificate generated by your Identity Provider>")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] content: The content of the SAML certificate
        :param pulumi.Input[_builtins.str] organization_id: The organization ID. If not provided, the default organization configured in the provider is used.
        :param pulumi.Input[_builtins.str] saml_id: The ID of the SAML configuration. If not provided, the organization's SAML configuration is used.
        :param pulumi.Input[_builtins.str] type: The type of the SAML certificate. Possible values are: `signing`, `encryption`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SamlCertificateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages SAML certificates for an organization. SAML certificates are used to establish trust between your organization and identity providers. SAML (Security Assertion Markup Language) is an open standard for exchanging authentication and authorization data between parties, specifically between an identity provider and a service provider. This resource allows you to manage SAML certificates in your Scaleway organization.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        ### Enable IAM SAML for the default organization and add a signing certificate
        test = scaleway.iam.Saml("test")
        main = scaleway.iam.SamlCertificate("main",
            saml_id=test.id,
            type="signing",
            content="<signing certificate generated by your Identity Provider>")
        ```

        :param str resource_name: The name of the resource.
        :param SamlCertificateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SamlCertificateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 saml_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SamlCertificateArgs.__new__(SamlCertificateArgs)

            if content is None and not opts.urn:
                raise TypeError("Missing required property 'content'")
            __props__.__dict__["content"] = content
            __props__.__dict__["organization_id"] = organization_id
            __props__.__dict__["saml_id"] = saml_id
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["expires_at"] = None
            __props__.__dict__["origin"] = None
        super(SamlCertificate, __self__).__init__(
            'scaleway:iam/samlCertificate:SamlCertificate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            content: Optional[pulumi.Input[_builtins.str]] = None,
            expires_at: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            origin: Optional[pulumi.Input[_builtins.str]] = None,
            saml_id: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'SamlCertificate':
        """
        Get an existing SamlCertificate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] content: The content of the SAML certificate
        :param pulumi.Input[_builtins.str] expires_at: (String) The expiration date and time of the SAML certificate
        :param pulumi.Input[_builtins.str] organization_id: The organization ID. If not provided, the default organization configured in the provider is used.
        :param pulumi.Input[_builtins.str] origin: (String) The origin of the SAML certificate. Possible values are: `scaleway`, `identity_provider`.
        :param pulumi.Input[_builtins.str] saml_id: The ID of the SAML configuration. If not provided, the organization's SAML configuration is used.
        :param pulumi.Input[_builtins.str] type: The type of the SAML certificate. Possible values are: `signing`, `encryption`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SamlCertificateState.__new__(_SamlCertificateState)

        __props__.__dict__["content"] = content
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["origin"] = origin
        __props__.__dict__["saml_id"] = saml_id
        __props__.__dict__["type"] = type
        return SamlCertificate(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def content(self) -> pulumi.Output[_builtins.str]:
        """
        The content of the SAML certificate
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[_builtins.str]:
        """
        (String) The expiration date and time of the SAML certificate
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The organization ID. If not provided, the default organization configured in the provider is used.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter
    def origin(self) -> pulumi.Output[_builtins.str]:
        """
        (String) The origin of the SAML certificate. Possible values are: `scaleway`, `identity_provider`.
        """
        return pulumi.get(self, "origin")

    @_builtins.property
    @pulumi.getter(name="samlId")
    def saml_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the SAML configuration. If not provided, the organization's SAML configuration is used.
        """
        return pulumi.get(self, "saml_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the SAML certificate. Possible values are: `signing`, `encryption`.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ImageArgs', 'Image']

@pulumi.input_type
class ImageArgs:
    def __init__(__self__, *,
                 root_volume_id: pulumi.Input[_builtins.str],
                 additional_volume_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 architecture: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Image resource.
        :param pulumi.Input[_builtins.str] root_volume_id: The ID of the snapshot of the volume to be used as root in the image.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] additional_volume_ids: List of IDs of the snapshots of the additional volumes to be attached to the image.
        :param pulumi.Input[_builtins.str] architecture: The architecture the image is compatible with. Possible values are: `x86_64` or `arm`.
        :param pulumi.Input[_builtins.str] name: The name of the image. If not provided it will be randomly generated.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project the image is associated with.
        :param pulumi.Input[_builtins.bool] public: Set to `true` if the image is public.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags to apply to the image.
        :param pulumi.Input[_builtins.str] zone: The zone in which the image should be created.
        """
        pulumi.set(__self__, "root_volume_id", root_volume_id)
        if additional_volume_ids is not None:
            pulumi.set(__self__, "additional_volume_ids", additional_volume_ids)
        if architecture is not None:
            pulumi.set(__self__, "architecture", architecture)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public is not None:
            pulumi.set(__self__, "public", public)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="rootVolumeId")
    def root_volume_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the snapshot of the volume to be used as root in the image.
        """
        return pulumi.get(self, "root_volume_id")

    @root_volume_id.setter
    def root_volume_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "root_volume_id", value)

    @_builtins.property
    @pulumi.getter(name="additionalVolumeIds")
    def additional_volume_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of IDs of the snapshots of the additional volumes to be attached to the image.
        """
        return pulumi.get(self, "additional_volume_ids")

    @additional_volume_ids.setter
    def additional_volume_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "additional_volume_ids", value)

    @_builtins.property
    @pulumi.getter
    def architecture(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The architecture the image is compatible with. Possible values are: `x86_64` or `arm`.
        """
        return pulumi.get(self, "architecture")

    @architecture.setter
    def architecture(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "architecture", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the image. If not provided it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project the image is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def public(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to `true` if the image is public.
        """
        return pulumi.get(self, "public")

    @public.setter
    def public(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "public", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of tags to apply to the image.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The zone in which the image should be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _ImageState:
    def __init__(__self__, *,
                 additional_volume_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 additional_volumes: Optional[pulumi.Input[Sequence[pulumi.Input['ImageAdditionalVolumeArgs']]]] = None,
                 architecture: Optional[pulumi.Input[_builtins.str]] = None,
                 creation_date: Optional[pulumi.Input[_builtins.str]] = None,
                 from_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 modification_date: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public: Optional[pulumi.Input[_builtins.bool]] = None,
                 root_volume_id: Optional[pulumi.Input[_builtins.str]] = None,
                 root_volumes: Optional[pulumi.Input[Sequence[pulumi.Input['ImageRootVolumeArgs']]]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Image resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] additional_volume_ids: List of IDs of the snapshots of the additional volumes to be attached to the image.
        :param pulumi.Input[Sequence[pulumi.Input['ImageAdditionalVolumeArgs']]] additional_volumes: The description of the extra volumes attached to the image.
        :param pulumi.Input[_builtins.str] architecture: The architecture the image is compatible with. Possible values are: `x86_64` or `arm`.
        :param pulumi.Input[_builtins.str] creation_date: Date of the image creation.
        :param pulumi.Input[_builtins.str] from_server_id: ID of the server the image is based on (in case it is a backup).
        :param pulumi.Input[_builtins.str] modification_date: Date of image latest update.
        :param pulumi.Input[_builtins.str] name: The name of the image. If not provided it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID the image is associated with.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project the image is associated with.
        :param pulumi.Input[_builtins.bool] public: Set to `true` if the image is public.
        :param pulumi.Input[_builtins.str] root_volume_id: The ID of the snapshot of the volume to be used as root in the image.
        :param pulumi.Input[Sequence[pulumi.Input['ImageRootVolumeArgs']]] root_volumes: The description of the root volume attached to the image.
        :param pulumi.Input[_builtins.str] state: State of the image. Possible values are: `available`, `creating` or `error`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags to apply to the image.
        :param pulumi.Input[_builtins.str] zone: The zone in which the image should be created.
        """
        if additional_volume_ids is not None:
            pulumi.set(__self__, "additional_volume_ids", additional_volume_ids)
        if additional_volumes is not None:
            pulumi.set(__self__, "additional_volumes", additional_volumes)
        if architecture is not None:
            pulumi.set(__self__, "architecture", architecture)
        if creation_date is not None:
            pulumi.set(__self__, "creation_date", creation_date)
        if from_server_id is not None:
            pulumi.set(__self__, "from_server_id", from_server_id)
        if modification_date is not None:
            pulumi.set(__self__, "modification_date", modification_date)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if public is not None:
            pulumi.set(__self__, "public", public)
        if root_volume_id is not None:
            pulumi.set(__self__, "root_volume_id", root_volume_id)
        if root_volumes is not None:
            pulumi.set(__self__, "root_volumes", root_volumes)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter(name="additionalVolumeIds")
    def additional_volume_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of IDs of the snapshots of the additional volumes to be attached to the image.
        """
        return pulumi.get(self, "additional_volume_ids")

    @additional_volume_ids.setter
    def additional_volume_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "additional_volume_ids", value)

    @_builtins.property
    @pulumi.getter(name="additionalVolumes")
    def additional_volumes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ImageAdditionalVolumeArgs']]]]:
        """
        The description of the extra volumes attached to the image.
        """
        return pulumi.get(self, "additional_volumes")

    @additional_volumes.setter
    def additional_volumes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ImageAdditionalVolumeArgs']]]]):
        pulumi.set(self, "additional_volumes", value)

    @_builtins.property
    @pulumi.getter
    def architecture(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The architecture the image is compatible with. Possible values are: `x86_64` or `arm`.
        """
        return pulumi.get(self, "architecture")

    @architecture.setter
    def architecture(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "architecture", value)

    @_builtins.property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date of the image creation.
        """
        return pulumi.get(self, "creation_date")

    @creation_date.setter
    def creation_date(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creation_date", value)

    @_builtins.property
    @pulumi.getter(name="fromServerId")
    def from_server_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the server the image is based on (in case it is a backup).
        """
        return pulumi.get(self, "from_server_id")

    @from_server_id.setter
    def from_server_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "from_server_id", value)

    @_builtins.property
    @pulumi.getter(name="modificationDate")
    def modification_date(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Date of image latest update.
        """
        return pulumi.get(self, "modification_date")

    @modification_date.setter
    def modification_date(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "modification_date", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the image. If not provided it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID the image is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project the image is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def public(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Set to `true` if the image is public.
        """
        return pulumi.get(self, "public")

    @public.setter
    def public(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "public", value)

    @_builtins.property
    @pulumi.getter(name="rootVolumeId")
    def root_volume_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the snapshot of the volume to be used as root in the image.
        """
        return pulumi.get(self, "root_volume_id")

    @root_volume_id.setter
    def root_volume_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "root_volume_id", value)

    @_builtins.property
    @pulumi.getter(name="rootVolumes")
    def root_volumes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ImageRootVolumeArgs']]]]:
        """
        The description of the root volume attached to the image.
        """
        return pulumi.get(self, "root_volumes")

    @root_volumes.setter
    def root_volumes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ImageRootVolumeArgs']]]]):
        pulumi.set(self, "root_volumes", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        State of the image. Possible values are: `available`, `creating` or `error`.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of tags to apply to the image.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The zone in which the image should be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("scaleway:instance/image:Image")
class Image(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_volume_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 architecture: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public: Optional[pulumi.Input[_builtins.bool]] = None,
                 root_volume_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Compute Images.
        For more information, see the [API documentation](https://www.scaleway.com/en/developers/api/instance/#path-images-list-instance-images).

        ## Example Usage

        ### From a volume

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        volume = scaleway.instance.Volume("volume",
            type="b_ssd",
            size_in_gb=20)
        volume_snapshot = scaleway.instance.Snapshot("volume_snapshot", volume_id=volume.id)
        volume_image = scaleway.instance.Image("volume_image",
            name="image_from_volume",
            root_volume_id=volume_snapshot.id)
        ```

        ### From a server

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        server = scaleway.instance.Server("server",
            image="ubuntu_jammy",
            type="DEV1-S")
        server_snapshot = scaleway.instance.Snapshot("server_snapshot", volume_id=main["rootVolume"][0]["volumeId"])
        server_image = scaleway.instance.Image("server_image",
            name="image_from_server",
            root_volume_id=server_snapshot.id)
        ```

        ### With additional volumes

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        server = scaleway.instance.Server("server",
            image="ubuntu_jammy",
            type="DEV1-S")
        volume = scaleway.instance.Volume("volume",
            type="b_ssd",
            size_in_gb=20)
        volume_snapshot = scaleway.instance.Snapshot("volume_snapshot", volume_id=volume.id)
        server_snapshot = scaleway.instance.Snapshot("server_snapshot", volume_id=main["rootVolume"][0]["volumeId"])
        image = scaleway.instance.Image("image",
            name="image_with_extra_volumes",
            root_volume_id=server_snapshot.id,
            additional_volume_ids=[volume_snapshot.id])
        ```

        ## Import

        Images can be imported using the `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:instance/image:Image main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] additional_volume_ids: List of IDs of the snapshots of the additional volumes to be attached to the image.
        :param pulumi.Input[_builtins.str] architecture: The architecture the image is compatible with. Possible values are: `x86_64` or `arm`.
        :param pulumi.Input[_builtins.str] name: The name of the image. If not provided it will be randomly generated.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project the image is associated with.
        :param pulumi.Input[_builtins.bool] public: Set to `true` if the image is public.
        :param pulumi.Input[_builtins.str] root_volume_id: The ID of the snapshot of the volume to be used as root in the image.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags to apply to the image.
        :param pulumi.Input[_builtins.str] zone: The zone in which the image should be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ImageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Compute Images.
        For more information, see the [API documentation](https://www.scaleway.com/en/developers/api/instance/#path-images-list-instance-images).

        ## Example Usage

        ### From a volume

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        volume = scaleway.instance.Volume("volume",
            type="b_ssd",
            size_in_gb=20)
        volume_snapshot = scaleway.instance.Snapshot("volume_snapshot", volume_id=volume.id)
        volume_image = scaleway.instance.Image("volume_image",
            name="image_from_volume",
            root_volume_id=volume_snapshot.id)
        ```

        ### From a server

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        server = scaleway.instance.Server("server",
            image="ubuntu_jammy",
            type="DEV1-S")
        server_snapshot = scaleway.instance.Snapshot("server_snapshot", volume_id=main["rootVolume"][0]["volumeId"])
        server_image = scaleway.instance.Image("server_image",
            name="image_from_server",
            root_volume_id=server_snapshot.id)
        ```

        ### With additional volumes

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        server = scaleway.instance.Server("server",
            image="ubuntu_jammy",
            type="DEV1-S")
        volume = scaleway.instance.Volume("volume",
            type="b_ssd",
            size_in_gb=20)
        volume_snapshot = scaleway.instance.Snapshot("volume_snapshot", volume_id=volume.id)
        server_snapshot = scaleway.instance.Snapshot("server_snapshot", volume_id=main["rootVolume"][0]["volumeId"])
        image = scaleway.instance.Image("image",
            name="image_with_extra_volumes",
            root_volume_id=server_snapshot.id,
            additional_volume_ids=[volume_snapshot.id])
        ```

        ## Import

        Images can be imported using the `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:instance/image:Image main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ImageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ImageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_volume_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 architecture: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 public: Optional[pulumi.Input[_builtins.bool]] = None,
                 root_volume_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ImageArgs.__new__(ImageArgs)

            __props__.__dict__["additional_volume_ids"] = additional_volume_ids
            __props__.__dict__["architecture"] = architecture
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["public"] = public
            if root_volume_id is None and not opts.urn:
                raise TypeError("Missing required property 'root_volume_id'")
            __props__.__dict__["root_volume_id"] = root_volume_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["zone"] = zone
            __props__.__dict__["additional_volumes"] = None
            __props__.__dict__["creation_date"] = None
            __props__.__dict__["from_server_id"] = None
            __props__.__dict__["modification_date"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["root_volumes"] = None
            __props__.__dict__["state"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/instanceImage:InstanceImage")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Image, __self__).__init__(
            'scaleway:instance/image:Image',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_volume_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            additional_volumes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageAdditionalVolumeArgs', 'ImageAdditionalVolumeArgsDict']]]]] = None,
            architecture: Optional[pulumi.Input[_builtins.str]] = None,
            creation_date: Optional[pulumi.Input[_builtins.str]] = None,
            from_server_id: Optional[pulumi.Input[_builtins.str]] = None,
            modification_date: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            public: Optional[pulumi.Input[_builtins.bool]] = None,
            root_volume_id: Optional[pulumi.Input[_builtins.str]] = None,
            root_volumes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ImageRootVolumeArgs', 'ImageRootVolumeArgsDict']]]]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'Image':
        """
        Get an existing Image resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] additional_volume_ids: List of IDs of the snapshots of the additional volumes to be attached to the image.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ImageAdditionalVolumeArgs', 'ImageAdditionalVolumeArgsDict']]]] additional_volumes: The description of the extra volumes attached to the image.
        :param pulumi.Input[_builtins.str] architecture: The architecture the image is compatible with. Possible values are: `x86_64` or `arm`.
        :param pulumi.Input[_builtins.str] creation_date: Date of the image creation.
        :param pulumi.Input[_builtins.str] from_server_id: ID of the server the image is based on (in case it is a backup).
        :param pulumi.Input[_builtins.str] modification_date: Date of image latest update.
        :param pulumi.Input[_builtins.str] name: The name of the image. If not provided it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The organization ID the image is associated with.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project the image is associated with.
        :param pulumi.Input[_builtins.bool] public: Set to `true` if the image is public.
        :param pulumi.Input[_builtins.str] root_volume_id: The ID of the snapshot of the volume to be used as root in the image.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ImageRootVolumeArgs', 'ImageRootVolumeArgsDict']]]] root_volumes: The description of the root volume attached to the image.
        :param pulumi.Input[_builtins.str] state: State of the image. Possible values are: `available`, `creating` or `error`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags to apply to the image.
        :param pulumi.Input[_builtins.str] zone: The zone in which the image should be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ImageState.__new__(_ImageState)

        __props__.__dict__["additional_volume_ids"] = additional_volume_ids
        __props__.__dict__["additional_volumes"] = additional_volumes
        __props__.__dict__["architecture"] = architecture
        __props__.__dict__["creation_date"] = creation_date
        __props__.__dict__["from_server_id"] = from_server_id
        __props__.__dict__["modification_date"] = modification_date
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["public"] = public
        __props__.__dict__["root_volume_id"] = root_volume_id
        __props__.__dict__["root_volumes"] = root_volumes
        __props__.__dict__["state"] = state
        __props__.__dict__["tags"] = tags
        __props__.__dict__["zone"] = zone
        return Image(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="additionalVolumeIds")
    def additional_volume_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of IDs of the snapshots of the additional volumes to be attached to the image.
        """
        return pulumi.get(self, "additional_volume_ids")

    @_builtins.property
    @pulumi.getter(name="additionalVolumes")
    def additional_volumes(self) -> pulumi.Output[Sequence['outputs.ImageAdditionalVolume']]:
        """
        The description of the extra volumes attached to the image.
        """
        return pulumi.get(self, "additional_volumes")

    @_builtins.property
    @pulumi.getter
    def architecture(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The architecture the image is compatible with. Possible values are: `x86_64` or `arm`.
        """
        return pulumi.get(self, "architecture")

    @_builtins.property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> pulumi.Output[_builtins.str]:
        """
        Date of the image creation.
        """
        return pulumi.get(self, "creation_date")

    @_builtins.property
    @pulumi.getter(name="fromServerId")
    def from_server_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the server the image is based on (in case it is a backup).
        """
        return pulumi.get(self, "from_server_id")

    @_builtins.property
    @pulumi.getter(name="modificationDate")
    def modification_date(self) -> pulumi.Output[_builtins.str]:
        """
        Date of image latest update.
        """
        return pulumi.get(self, "modification_date")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the image. If not provided it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The organization ID the image is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the project the image is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def public(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Set to `true` if the image is public.
        """
        return pulumi.get(self, "public")

    @_builtins.property
    @pulumi.getter(name="rootVolumeId")
    def root_volume_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the snapshot of the volume to be used as root in the image.
        """
        return pulumi.get(self, "root_volume_id")

    @_builtins.property
    @pulumi.getter(name="rootVolumes")
    def root_volumes(self) -> pulumi.Output[Sequence['outputs.ImageRootVolume']]:
        """
        The description of the root volume attached to the image.
        """
        return pulumi.get(self, "root_volumes")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        State of the image. Possible values are: `available`, `creating` or `error`.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of tags to apply to the image.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The zone in which the image should be created.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRouteStageResult',
    'AwaitableGetRouteStageResult',
    'get_route_stage',
    'get_route_stage_output',
]

@pulumi.output_type
class GetRouteStageResult:
    """
    A collection of values returned by getRouteStage.
    """
    def __init__(__self__, backend_stage_id=None, created_at=None, id=None, pipeline_id=None, project_id=None, route_stage_id=None, rules=None, updated_at=None, waf_stage_id=None):
        if backend_stage_id and not isinstance(backend_stage_id, str):
            raise TypeError("Expected argument 'backend_stage_id' to be a str")
        pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if pipeline_id and not isinstance(pipeline_id, str):
            raise TypeError("Expected argument 'pipeline_id' to be a str")
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if route_stage_id and not isinstance(route_stage_id, str):
            raise TypeError("Expected argument 'route_stage_id' to be a str")
        pulumi.set(__self__, "route_stage_id", route_stage_id)
        if rules and not isinstance(rules, list):
            raise TypeError("Expected argument 'rules' to be a list")
        pulumi.set(__self__, "rules", rules)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if waf_stage_id and not isinstance(waf_stage_id, str):
            raise TypeError("Expected argument 'waf_stage_id' to be a str")
        pulumi.set(__self__, "waf_stage_id", waf_stage_id)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> _builtins.str:
        return pulumi.get(self, "backend_stage_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "pipeline_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="routeStageId")
    def route_stage_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "route_stage_id")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Sequence['outputs.GetRouteStageRuleResult']:
        return pulumi.get(self, "rules")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="wafStageId")
    def waf_stage_id(self) -> _builtins.str:
        return pulumi.get(self, "waf_stage_id")


class AwaitableGetRouteStageResult(GetRouteStageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRouteStageResult(
            backend_stage_id=self.backend_stage_id,
            created_at=self.created_at,
            id=self.id,
            pipeline_id=self.pipeline_id,
            project_id=self.project_id,
            route_stage_id=self.route_stage_id,
            rules=self.rules,
            updated_at=self.updated_at,
            waf_stage_id=self.waf_stage_id)


def get_route_stage(pipeline_id: Optional[_builtins.str] = None,
                    route_stage_id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRouteStageResult:
    """
    Gets information about an Edge Services route stage.

    A route stage defines HTTP request routing rules that forward requests to different backend stages based on method and path matching.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services route stage by its ID
    by_id = scaleway.edgeservices.get_route_stage(route_stage_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services route stage by pipeline ID
    by_pipeline = scaleway.edgeservices.get_route_stage(pipeline_id=main["id"])
    ```


    :param _builtins.str pipeline_id: The ID of the pipeline.
    :param _builtins.str route_stage_id: The ID of the route stage. Conflicts with all filter arguments below.
           
           The following filter arguments are supported (cannot be used with `route_stage_id`):
    """
    __args__ = dict()
    __args__['pipelineId'] = pipeline_id
    __args__['routeStageId'] = route_stage_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:edgeservices/getRouteStage:getRouteStage', __args__, opts=opts, typ=GetRouteStageResult).value

    return AwaitableGetRouteStageResult(
        backend_stage_id=pulumi.get(__ret__, 'backend_stage_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        pipeline_id=pulumi.get(__ret__, 'pipeline_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        route_stage_id=pulumi.get(__ret__, 'route_stage_id'),
        rules=pulumi.get(__ret__, 'rules'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        waf_stage_id=pulumi.get(__ret__, 'waf_stage_id'))
def get_route_stage_output(pipeline_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           route_stage_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRouteStageResult]:
    """
    Gets information about an Edge Services route stage.

    A route stage defines HTTP request routing rules that forward requests to different backend stages based on method and path matching.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services route stage by its ID
    by_id = scaleway.edgeservices.get_route_stage(route_stage_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services route stage by pipeline ID
    by_pipeline = scaleway.edgeservices.get_route_stage(pipeline_id=main["id"])
    ```


    :param _builtins.str pipeline_id: The ID of the pipeline.
    :param _builtins.str route_stage_id: The ID of the route stage. Conflicts with all filter arguments below.
           
           The following filter arguments are supported (cannot be used with `route_stage_id`):
    """
    __args__ = dict()
    __args__['pipelineId'] = pipeline_id
    __args__['routeStageId'] = route_stage_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:edgeservices/getRouteStage:getRouteStage', __args__, opts=opts, typ=GetRouteStageResult)
    return __ret__.apply(lambda __response__: GetRouteStageResult(
        backend_stage_id=pulumi.get(__response__, 'backend_stage_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        pipeline_id=pulumi.get(__response__, 'pipeline_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        route_stage_id=pulumi.get(__response__, 'route_stage_id'),
        rules=pulumi.get(__response__, 'rules'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        waf_stage_id=pulumi.get(__response__, 'waf_stage_id')))
